<?php
/**
 * VW Travel Theme Customizer
 *
 * @package VW Travel
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_travel_custom_controls() {
    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_travel_custom_controls' );

function vw_travel_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-picker.php' );

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage'; 
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array( 
		'selector' => '.logo .site-title a', 
	 	'render_callback' => 'vw_travel_customize_partial_blogname', 
	)); 

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
		'selector' => 'p.site-description', 
		'render_callback' => 'vw_travel_customize_partial_blogdescription', 
	));

	//add home page setting pannel
	$VWTravelParentPanel = new VW_Travel_WP_Customize_Panel( $wp_customize, 'vw_travel_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'VW Settings', 'vw-travel' ),
		'priority' => 10,
	));

	$wp_customize->add_panel( $VWTravelParentPanel );

	$HomePageParentPanel = new VW_Travel_WP_Customize_Panel( $wp_customize, 'vw_travel_homepage_panel', array(
		'title' => __( 'Homepage Settings', 'vw-travel' ),
		'panel' => 'vw_travel_panel_id',
	));

	$wp_customize->add_panel( $HomePageParentPanel );

	//Topbar
	$wp_customize->add_section( 'vw_travel_topbar', array(
    	'title'      => __( 'Topbar Settings', 'vw-travel' ),
		'panel' => 'vw_travel_homepage_panel'
	) );

   	// Header Background color
	$wp_customize->add_setting('vw_travel_header_background_color', array(
		'default'           => '#222222',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_travel_header_background_color', array(
		'label'    => __('Header Background Color', 'vw-travel'),
		'section'  => 'header_image',
	)));

	$wp_customize->add_setting('vw_travel_header_img_position',array(
	  'default' => 'center top',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_header_img_position',array(
		'type' => 'select',
		'label' => __('Header Image Position','vw-travel'),
		'section' => 'header_image',
		'choices' 	=> array(
			'left top' 		=> esc_html__( 'Top Left', 'vw-travel' ),
			'center top'   => esc_html__( 'Top', 'vw-travel' ),
			'right top'   => esc_html__( 'Top Right', 'vw-travel' ),
			'left center'   => esc_html__( 'Left', 'vw-travel' ),
			'center center'   => esc_html__( 'Center', 'vw-travel' ),
			'right center'   => esc_html__( 'Right', 'vw-travel' ),
			'left bottom'   => esc_html__( 'Bottom Left', 'vw-travel' ),
			'center bottom'   => esc_html__( 'Bottom', 'vw-travel' ),
			'right bottom'   => esc_html__( 'Bottom Right', 'vw-travel' ),
		),
	));

	$wp_customize->add_setting( 'vw_travel_topbar_hide_show',
       array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_travel_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_topbar_hide_show',
       array(
      'label' => esc_html__( 'Show / Hide Topbar','vw-travel' ),
      'section' => 'vw_travel_topbar'
    )));

    $wp_customize->add_setting('vw_travel_topbar_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_topbar_padding_top_bottom',array(
		'label'	=> __('Topbar Padding Top Bottom','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_topbar',
		'type'=> 'text'
	));

    //Sticky Header
	$wp_customize->add_setting( 'vw_travel_sticky_header',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_travel_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_sticky_header',array(
        'label' => esc_html__( 'Show / Hide Sticky Header','vw-travel' ),
        'section' => 'vw_travel_topbar'
    )));

    $wp_customize->add_setting('vw_travel_sticky_header_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_sticky_header_padding',array(
		'label'	=> __('Sticky Header Padding','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_travel_header_search',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_travel_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_header_search',
       array(
		'label' => esc_html__( 'Show / Hide Search','vw-travel' ),
		'section' => 'vw_travel_topbar'
    )));

    $wp_customize->add_setting('vw_travel_search_icon',array(
		'default'	=> 'fas fa-search',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_search_icon',array(
		'label'	=> __('Add Search Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_topbar',
		'setting'	=> 'vw_travel_search_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_travel_search_close_icon',array(
		'default'	=> 'fa fa-window-close',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_search_close_icon',array(
		'label'	=> __('Add Search Close Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_topbar',
		'setting'	=> 'vw_travel_search_close_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting('vw_travel_search_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_search_font_size',array(
		'label'	=> __('Search Font Size','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_search_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_search_padding_top_bottom',array(
		'label'	=> __('Search Padding Top Bottom','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_search_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_search_padding_left_right',array(
		'label'	=> __('Search Padding Left Right','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_travel_search_border_radius', array(
		'default'              => "",
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_travel_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_travel_search_border_radius', array(
		'label'       => esc_html__( 'Search Border Radius','vw-travel' ),
		'section'     => 'vw_travel_topbar',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_travel_location', array( 
		'selector' => 'p.email-id', 
		'render_callback' => 'vw_travel_customize_partial_vw_travel_location', 
	));

    $wp_customize->add_setting('vw_travel_location_icon',array(
		'default'	=> 'fas fa-location-arrow',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_location_icon',array(
		'label'	=> __('Add Location Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_topbar',
		'setting'	=> 'vw_travel_location_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_travel_location',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_location',array(
		'label'	=> __('Add Location','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '828 N. Iqyreesrs Street Liocnss Park', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_phone_number',array(
		'default'=> '',
		'sanitize_callback'	=> 'vw_travel_sanitize_phone_number'
	));
	$wp_customize->add_control('vw_travel_phone_number',array(
		'label'	=> __('Add Phone Number','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '+00 987 654 1230', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_email_addres_icon',array(
		'default'	=> 'far fa-envelope',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_email_addres_icon',array(
		'label'	=> __('Add Email Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_topbar',
		'setting'	=> 'vw_travel_email_addres_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_travel_email_address',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_email'
	));
	$wp_customize->add_control('vw_travel_email_address',array(
		'label'	=> __('Add Email Address','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( 'example@gmail.com', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_topbar',
		'type'=> 'text'
	));

	//Menus Settings
	$wp_customize->add_section( 'vw_travel_menu_section' , array(
    	'title' => __( 'Menus Settings', 'vw-travel' ),
		'panel' => 'vw_travel_homepage_panel'
	) );

	$wp_customize->add_setting('vw_travel_navigation_menu_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_navigation_menu_font_size',array(
		'label'	=> __('Menus Font Size','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_menu_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_navigation_menu_font_weight',array(
        'default' => 900,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_navigation_menu_font_weight',array(
        'type' => 'select',
        'label' => __('Menus Font Weight','vw-travel'),
        'section' => 'vw_travel_menu_section',
        'choices' => array(
        	'100' => __('100','vw-travel'),
            '200' => __('200','vw-travel'),
            '300' => __('300','vw-travel'),
            '400' => __('400','vw-travel'),
            '500' => __('500','vw-travel'),
            '600' => __('600','vw-travel'),
            '700' => __('700','vw-travel'),
            '800' => __('800','vw-travel'),
            '900' => __('900','vw-travel'),
        ),
	) );

	// text trasform
	$wp_customize->add_setting('vw_travel_menu_text_transform',array(
		'default'=> 'Capitalize',
		'sanitize_callback'	=> 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_menu_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Menus Text Transform','vw-travel'),
		'choices' => array(
            'Uppercase' => __('Uppercase','vw-travel'),
            'Capitalize' => __('Capitalize','vw-travel'),
            'Lowercase' => __('Lowercase','vw-travel'),
        ),
		'section'=> 'vw_travel_menu_section',
	));

	$wp_customize->add_setting('vw_travel_menus_item_style',array(
        'default' => '',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_menus_item_style',array(
        'type' => 'select',
        'section' => 'vw_travel_menu_section',
		'label' => __('Menu Item Hover Style','vw-travel'),
		'choices' => array(
            'None' => __('None','vw-travel'),
            'Zoom In' => __('Zoom In','vw-travel'),
        ),
	) );

	$wp_customize->add_setting('vw_travel_header_menus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_travel_header_menus_color', array(
		'label'    => __('Menus Color', 'vw-travel'),
		'section'  => 'vw_travel_menu_section',
	)));

	$wp_customize->add_setting('vw_travel_header_menus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_travel_header_menus_hover_color', array(
		'label'    => __('Menus Hover Color', 'vw-travel'),
		'section'  => 'vw_travel_menu_section',
	)));

	$wp_customize->add_setting('vw_travel_header_submenus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_travel_header_submenus_color', array(
		'label'    => __('Sub Menus Color', 'vw-travel'),
		'section'  => 'vw_travel_menu_section',
	)));

	$wp_customize->add_setting('vw_travel_header_submenus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_travel_header_submenus_hover_color', array(
		'label'    => __('Sub Menus Hover Color', 'vw-travel'),
		'section'  => 'vw_travel_menu_section',
	)));
    
	//Slider
	$wp_customize->add_section( 'vw_travel_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'vw-travel' ),
    	'description' => __('Free theme has 3 slides options, For unlimited slides and more options <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/wordpress-travel-theme/">GET PRO</a>','vw-travel'),
		'panel' => 'vw_travel_homepage_panel'
	) );

	$wp_customize->add_setting( 'vw_travel_slider_arrows',
       array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_travel_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_slider_arrows',
       array(
      'label' => esc_html__( 'Show / Hide Slider','vw-travel' ),
      'section' => 'vw_travel_slidersettings'
    )));

        $wp_customize->add_setting('vw_travel_slider_type',array(
        'default' => 'Default slider',
        'sanitize_callback' => 'vw_travel_sanitize_choices'
	) );
	$wp_customize->add_control('vw_travel_slider_type', array(
        'type' => 'select',
        'label' => __('Slider Type','vw-travel'),
        'section' => 'vw_travel_slidersettings',
        'choices' => array(
            'Default slider' => __('Default slider','vw-travel'),
            'Advance slider' => __('Advance slider','vw-travel'),
        ),
	));

	$wp_customize->add_setting('vw_travel_advance_slider_shortcode',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_advance_slider_shortcode',array(
		'label'	=> __('Add Slider Shortcode','vw-travel'),
		'section'=> 'vw_travel_slidersettings',
		'type'=> 'text',
		'active_callback' => 'vw_travel_advance_slider'
	));

    //Selective Refresh
    $wp_customize->selective_refresh->add_partial('vw_travel_slider_arrows',array(
		'selector'        => '#slider .inner_carousel h1',
		'render_callback' => 'vw_travel_customize_partial_vw_travel_slider_arrows',
	));

	for ( $count = 1; $count <= 3; $count++ ) {
		$wp_customize->add_setting( 'vw_travel_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'vw_travel_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'vw_travel_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'vw-travel' ),
			'description' => __('Slider image size (1500 x 765)','vw-travel'),
			'section'  => 'vw_travel_slidersettings',
			'type'     => 'dropdown-pages',
			'active_callback' => 'vw_travel_default_slider'
		) );
	}

	$wp_customize->add_setting('vw_travel_slider_button_text',array(
		'default'=> 'View Tours',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_slider_button_text',array(
		'label'	=> __('Add Slider Button Text','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( 'View Tours', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_slidersettings',
		'type'=> 'text',
		'active_callback' => 'vw_travel_default_slider'
	));

	$wp_customize->add_setting('vw_travel_topbar_btn_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('vw_travel_topbar_btn_link',array(
		'label'	=> esc_html__('Add Button Link','vw-travel'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'www.example-info.com', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_slidersettings',
		'type'=> 'url'
	));

	$wp_customize->add_setting('vw_travel_slider_button_icon',array(
		'default'	=> 'fas fa-long-arrow-alt-right',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_slider_button_icon',array(
		'label'	=> __('Add Slider Button Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_slidersettings',
		'setting'	=> 'vw_travel_slider_button_icon',
		'type'		=> 'icon',
		'active_callback' => 'vw_travel_default_slider'
	)));

	//content layout
	$wp_customize->add_setting('vw_travel_slider_content_option',array(
        'default' => 'Center',
        'sanitize_callback' => 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Travel_Image_Radio_Control($wp_customize, 'vw_travel_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','vw-travel'),
        'section' => 'vw_travel_slidersettings',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/slider-content1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/slider-content2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/slider-content3.png',
    ),'active_callback' => 'vw_travel_default_slider'
    )));

	//Slider content padding
    $wp_customize->add_setting('vw_travel_slider_content_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_slider_content_padding_top_bottom',array(
		'label'	=> __('Slider Content Padding Top Bottom','vw-travel'),
		'description'	=> __('Enter a value in %. Example:20%','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '50%', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_slidersettings',
		'type'=> 'text',
		'active_callback' => 'vw_travel_default_slider'
	));

	$wp_customize->add_setting('vw_travel_slider_content_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_slider_content_padding_left_right',array(
		'label'	=> __('Slider Content Padding Left Right','vw-travel'),
		'description'	=> __('Enter a value in %. Example:20%','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '50%', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_slidersettings',
		'type'=> 'text',
		'active_callback' => 'vw_travel_default_slider'
	));

	//Slider excerpt
	$wp_customize->add_setting( 'vw_travel_slider_excerpt_number', array(
		'default'              => 30,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_travel_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_travel_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','vw-travel' ),
		'section'     => 'vw_travel_slidersettings',
		'type'        => 'range',
		'settings'    => 'vw_travel_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 15,
			'max'              => 50,
		),
		'active_callback' => 'vw_travel_default_slider'
	) );

	//Slider height
	$wp_customize->add_setting('vw_travel_slider_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_slider_height',array(
		'label'	=> __('Slider Height','vw-travel'),
		'description'	=> __('Specify the slider height (px).','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '500px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_slidersettings',
		'type'=> 'text',
		'active_callback' => 'vw_travel_default_slider'
	));

	$wp_customize->add_setting( 'vw_travel_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'vw_travel_sanitize_float'
	) );
	$wp_customize->add_control( 'vw_travel_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','vw-travel'),
		'section' => 'vw_travel_slidersettings',
		'type'  => 'number',
		'active_callback' => 'vw_travel_default_slider'
	) );


	//Opacity
	$wp_customize->add_setting('vw_travel_slider_opacity_color',array(
      'default'              => 0.5,
      'sanitize_callback' => 'vw_travel_sanitize_choices'
	));

	$wp_customize->add_control( 'vw_travel_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','vw-travel' ),
	'section'     => 'vw_travel_slidersettings',
	'type'        => 'select',
	'settings'    => 'vw_travel_slider_opacity_color',
	'choices' => array(
      '0' =>  esc_attr('0','vw-travel'),
      '0.1' =>  esc_attr('0.1','vw-travel'),
      '0.2' =>  esc_attr('0.2','vw-travel'),
      '0.3' =>  esc_attr('0.3','vw-travel'),
      '0.4' =>  esc_attr('0.4','vw-travel'),
      '0.5' =>  esc_attr('0.5','vw-travel'),
      '0.6' =>  esc_attr('0.6','vw-travel'),
      '0.7' =>  esc_attr('0.7','vw-travel'),
      '0.8' =>  esc_attr('0.8','vw-travel'),
      '0.9' =>  esc_attr('0.9','vw-travel')
	),
	'active_callback' => 'vw_travel_default_slider'
	));

	$wp_customize->add_setting( 'vw_travel_slider_image_overlay',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_travel_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_slider_image_overlay',array(
      	'label' => esc_html__( 'Show / Hide Slider Image Overlay','vw-travel' ),
      	'section' => 'vw_travel_slidersettings',
      	'active_callback' => 'vw_travel_default_slider'
    )));

    $wp_customize->add_setting('vw_travel_slider_image_overlay_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_travel_slider_image_overlay_color', array(
		'label'    => __('Slider Image Overlay Color', 'vw-travel'),
		'section'  => 'vw_travel_slidersettings',
		'active_callback' => 'vw_travel_default_slider'
	)));

	//search tour Section
	$wp_customize->add_section('vw_travel_search_tour', array(
		'title'       => __('Search Tour Section', 'vw-travel'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-travel'),
		'priority'    => null,
		'panel'       => 'vw_travel_homepage_panel',
	));

	$wp_customize->add_setting('vw_travel_search_tour_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_search_tour_text',array(
		'description' => __('<p>1. More options for search tour section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for search tour section.</p>','vw-travel'),
		'section'=> 'vw_travel_search_tour',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_travel_search_tour_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_search_tour_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_travel_guide') ." '>More Info</a>",
		'section'=> 'vw_travel_search_tour',
		'type'=> 'hidden'
	));

	//tour places Section
	$wp_customize->add_section('vw_travel_tour_places', array(
		'title'       => __('Tour Places Section', 'vw-travel'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-travel'),
		'priority'    => null,
		'panel'       => 'vw_travel_homepage_panel',
	));

	$wp_customize->add_setting('vw_travel_tour_places_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_tour_places_text',array(
		'description' => __('<p>1. More options for tour places section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for tour places section.</p>','vw-travel'),
		'section'=> 'vw_travel_tour_places',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_travel_tour_places_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_tour_places_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_travel_guide') ." '>More Info</a>",
		'section'=> 'vw_travel_tour_places',
		'type'=> 'hidden'
	));

	//tour interest Section
	$wp_customize->add_section('vw_travel_tour_interest', array(
		'title'       => __('Tour Interest Section', 'vw-travel'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-travel'),
		'priority'    => null,
		'panel'       => 'vw_travel_homepage_panel',
	));

	$wp_customize->add_setting('vw_travel_tour_interest_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_tour_interest_text',array(
		'description' => __('<p>1. More options for tour interest section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for tour interest section.</p>','vw-travel'),
		'section'=> 'vw_travel_tour_interest',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_travel_tour_interest_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_tour_interest_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_travel_guide') ." '>More Info</a>",
		'section'=> 'vw_travel_tour_interest',
		'type'=> 'hidden'
	));

	//popular tour Section
	$wp_customize->add_section('vw_travel_popular_tour', array(
		'title'       => __('Popular Tour Section', 'vw-travel'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-travel'),
		'priority'    => null,
		'panel'       => 'vw_travel_homepage_panel',
	));

	$wp_customize->add_setting('vw_travel_popular_tour_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_popular_tour_text',array(
		'description' => __('<p>1. More options for popular tour section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for popular tour section.</p>','vw-travel'),
		'section'=> 'vw_travel_popular_tour',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_travel_popular_tour_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_popular_tour_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_travel_guide') ." '>More Info</a>",
		'section'=> 'vw_travel_popular_tour',
		'type'=> 'hidden'
	));
    
	//Top Destination section
	$wp_customize->add_section( 'vw_travel_top_destination_section' , array(
    	'title'      => __( 'Top Destination Settings', 'vw-travel' ),
    	'description' => __('For more options of the top destination section<a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/wordpress-travel-theme/">GET PRO</a>','vw-travel'),
		'priority'   => null,
		'panel' => 'vw_travel_homepage_panel'
	) );

	$wp_customize->add_setting( 'vw_travel_post_hide_show',
       array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_travel_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_post_hide_show',
       array(
      'label' => esc_html__( 'Show / Hide Top Destination','vw-travel' ),
      'section' => 'vw_travel_top_destination_section'
    )));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_travel_section_title', array( 
		'selector' => '#top-destination h2', 
		'render_callback' => 'vw_travel_customize_partial_vw_travel_section_title',
	));

	$wp_customize->add_setting('vw_travel_section_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_section_title',array(
		'label'	=> __('Add Section Title','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( 'Explore Top Destination', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_top_destination_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_top_destination_number',array(
		'default'	=> 0,
		'sanitize_callback'	=> 'sanitize_text_field',
	));
	$wp_customize->add_control('vw_travel_top_destination_number',array(
		'label'	=> __('Number of Top Destination to show','vw-travel'),
		'description' => __('Images Size (370 x 360)','vw-travel'),
		'section'	=> 'vw_travel_top_destination_section',
		'type'		=> 'number'
	));

	//tour type Section
	$wp_customize->add_section('vw_travel_tour_type', array(
		'title'       => __('Tour Type Section', 'vw-travel'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-travel'),
		'priority'    => null,
		'panel'       => 'vw_travel_homepage_panel',
	));

	$wp_customize->add_setting('vw_travel_tour_type_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_tour_type_text',array(
		'description' => __('<p>1. More options for tour type section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for tour type section.</p>','vw-travel'),
		'section'=> 'vw_travel_tour_type',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_travel_tour_type_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_tour_type_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_travel_guide') ." '>More Info</a>",
		'section'=> 'vw_travel_tour_type',
		'type'=> 'hidden'
	));

	//popular tour Section
	$wp_customize->add_section('vw_travel_popular_tour', array(
		'title'       => __('Popular Tour Section', 'vw-travel'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-travel'),
		'priority'    => null,
		'panel'       => 'vw_travel_homepage_panel',
	));

	$wp_customize->add_setting('vw_travel_popular_tour_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_popular_tour_text',array(
		'description' => __('<p>1. More options for popular tour section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for popular tour section.</p>','vw-travel'),
		'section'=> 'vw_travel_popular_tour',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_travel_popular_tour_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_popular_tour_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_travel_guide') ." '>More Info</a>",
		'section'=> 'vw_travel_popular_tour',
		'type'=> 'hidden'
	));

	//hotels Section
	$wp_customize->add_section('vw_travel_hotels', array(
		'title'       => __('Hotels Section', 'vw-travel'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-travel'),
		'priority'    => null,
		'panel'       => 'vw_travel_homepage_panel',
	));

	$wp_customize->add_setting('vw_travel_hotels_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_hotels_text',array(
		'description' => __('<p>1. More options for hotels section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for hotels section.</p>','vw-travel'),
		'section'=> 'vw_travel_hotels',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_travel_hotels_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_hotels_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_travel_guide') ." '>More Info</a>",
		'section'=> 'vw_travel_hotels',
		'type'=> 'hidden'
	));

	//newsletter Section
	$wp_customize->add_section('vw_travel_newsletter', array(
		'title'       => __('Newsletter Section', 'vw-travel'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-travel'),
		'priority'    => null,
		'panel'       => 'vw_travel_homepage_panel',
	));

	$wp_customize->add_setting('vw_travel_newsletter_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_newsletter_text',array(
		'description' => __('<p>1. More options for newsletter section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for newsletter section.</p>','vw-travel'),
		'section'=> 'vw_travel_newsletter',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_travel_newsletter_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_newsletter_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_travel_guide') ." '>More Info</a>",
		'section'=> 'vw_travel_newsletter',
		'type'=> 'hidden'
	));

	//tour location Section
	$wp_customize->add_section('vw_travel_tour_location', array(
		'title'       => __('tour location Section', 'vw-travel'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-travel'),
		'priority'    => null,
		'panel'       => 'vw_travel_homepage_panel',
	));

	$wp_customize->add_setting('vw_travel_tour_location_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_tour_location_text',array(
		'description' => __('<p>1. More options for tour location section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for tour location section.</p>','vw-travel'),
		'section'=> 'vw_travel_tour_location',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_travel_tour_location_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_tour_location_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_travel_guide') ." '>More Info</a>",
		'section'=> 'vw_travel_tour_location',
		'type'=> 'hidden'
	));

	//testimonial Section
	$wp_customize->add_section('vw_travel_testimonial', array(
		'title'       => __('Testimonial Section', 'vw-travel'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-travel'),
		'priority'    => null,
		'panel'       => 'vw_travel_homepage_panel',
	));

	$wp_customize->add_setting('vw_travel_testimonial_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_testimonial_text',array(
		'description' => __('<p>1. More options for testimonial section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for testimonial section.</p>','vw-travel'),
		'section'=> 'vw_travel_testimonial',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_travel_testimonial_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_testimonial_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_travel_guide') ." '>More Info</a>",
		'section'=> 'vw_travel_testimonial',
		'type'=> 'hidden'
	));

	//blogs Section
	$wp_customize->add_section('vw_travel_blogs', array(
		'title'       => __('Blogs Section', 'vw-travel'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','vw-travel'),
		'priority'    => null,
		'panel'       => 'vw_travel_homepage_panel',
	));

	$wp_customize->add_setting('vw_travel_blogs_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_blogs_text',array(
		'description' => __('<p>1. More options for blogs section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for blogs section.</p>','vw-travel'),
		'section'=> 'vw_travel_blogs',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('vw_travel_blogs_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_blogs_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=vw_travel_guide') ." '>More Info</a>",
		'section'=> 'vw_travel_blogs',
		'type'=> 'hidden'
	));
	
	//Footer Text
	$wp_customize->add_section('vw_travel_footer',array(
		'title'	=> __('Footer Settings','vw-travel'),
		'description' => __('For more options of the footer section<a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/wordpress-travel-theme/">GET PRO</a>','vw-travel'),
		'panel' => 'vw_travel_homepage_panel',
	));	

	$wp_customize->add_setting( 'vw_travel_footer_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_travel_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_footer_hide_show',array(
      'label' => esc_html__( 'Show / Hide Footer','vw-travel' ),
      'section' => 'vw_travel_footer'
    )));

     // font size
	$wp_customize->add_setting('vw_travel_button_footer_font_size',array(
		'default'=> 25,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_button_footer_font_size',array(
		'label'	=> __('Footer Heading Font Size','vw-travel'),
  		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'vw_travel_footer',
	));

	$wp_customize->add_setting('vw_travel_button_footer_heading_letter_spacing',array(
		'default'=> 1,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_button_footer_heading_letter_spacing',array(
		'label'	=> __('Heading Letter Spacing','vw-travel'),
  		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
	),
		'section'=> 'vw_travel_footer',
	));

	// text trasform
	$wp_customize->add_setting('vw_travel_button_footer_text_transform',array(
		'default'=> 'Capitalize',
		'sanitize_callback'	=> 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_button_footer_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Heading Text Transform','vw-travel'),
		'choices' => array(
      'Uppercase' => __('Uppercase','vw-travel'),
      'Capitalize' => __('Capitalize','vw-travel'),
      'Lowercase' => __('Lowercase','vw-travel'),
    ),
		'section'=> 'vw_travel_footer',
	));

	$wp_customize->add_setting('vw_travel_footer_heading_weight',array(
        'default' => '',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_footer_heading_weight',array(
        'type' => 'select',
        'label' => __('Heading Font Weight','vw-travel'),
        'section' => 'vw_travel_footer',
        'choices' => array(
        	'100' => __('100','vw-travel'),
            '200' => __('200','vw-travel'),
            '300' => __('300','vw-travel'),
            '400' => __('400','vw-travel'),
            '500' => __('500','vw-travel'),
            '600' => __('600','vw-travel'),
            '700' => __('700','vw-travel'),
            '800' => __('800','vw-travel'),
            '900' => __('900','vw-travel'),
        ),
	) );

  	$wp_customize->add_setting('vw_travel_footer_template',array(
	    'default'	=> esc_html('vw-travel-footer-one'),
	    'sanitize_callback'	=> 'vw_travel_sanitize_choices'
  	));
 	$wp_customize->add_control('vw_travel_footer_template',array(
        'label'	=> esc_html__('Footer style','vw-travel'),
        'section'	=> 'vw_travel_footer',
        'setting'	=> 'vw_travel_footer_template',
        'type' => 'select',
        'choices' => array(
            'vw-travel-footer-one' => esc_html__('Style 1', 'vw-travel'),
            'vw-travel-footer-two' => esc_html__('Style 2', 'vw-travel'),
            'vw-travel-footer-three' => esc_html__('Style 3', 'vw-travel'),
            'vw-travel-footer-four' => esc_html__('Style 4', 'vw-travel'),
            'vw-travel-footer-five' => esc_html__('Style 5', 'vw-travel'),
        )
  	));

	$wp_customize->add_setting('vw_travel_footer_background_color', array(
		'default'           => '#1c1c1c',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_travel_footer_background_color', array(
		'label'    => __('Footer Background Color', 'vw-travel'),
		'section'  => 'vw_travel_footer',
	)));

	$wp_customize->add_setting('vw_travel_footer_background_image',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'vw_travel_footer_background_image',array(
        'label' => __('Footer Background Image','vw-travel'),
        'section' => 'vw_travel_footer'
	)));

	$wp_customize->add_setting('vw_travel_footer_img_position',array(
	  'default' => 'center center',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_footer_img_position',array(
		'type' => 'select',
		'label' => __('Footer Image Position','vw-travel'),
		'section' => 'vw_travel_footer',
		'choices' 	=> array(
			'left top' 		=> esc_html__( 'Top Left', 'vw-travel' ),
			'center top'   => esc_html__( 'Top', 'vw-travel' ),
			'right top'   => esc_html__( 'Top Right', 'vw-travel' ),
			'left center'   => esc_html__( 'Left', 'vw-travel' ),
			'center center'   => esc_html__( 'Center', 'vw-travel' ),
			'right center'   => esc_html__( 'Right', 'vw-travel' ),
			'left bottom'   => esc_html__( 'Bottom Left', 'vw-travel' ),
			'center bottom'   => esc_html__( 'Bottom', 'vw-travel' ),
			'right bottom'   => esc_html__( 'Bottom Right', 'vw-travel' ),
		),
	));

	// Footer
	$wp_customize->add_setting('vw_travel_img_footer',array(
		'default'=> 'scroll',
		'sanitize_callback'	=> 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_img_footer',array(
		'type' => 'select',
		'label'	=> __('Footer Background Attatchment','vw-travel'),
		'choices' => array(
            'fixed' => __('fixed','vw-travel'),
            'scroll' => __('scroll','vw-travel'),
        ),
		'section'=> 'vw_travel_footer',
	));

	// footer padding
	$wp_customize->add_setting('vw_travel_footer_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_footer_padding',array(
		'label'	=> __('Footer Top Bottom Padding','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
      'placeholder' => __( '10px', 'vw-travel' ),
    ),
		'section'=> 'vw_travel_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_footer_widgets_heading',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_footer_widgets_heading',array(
        'type' => 'select',
        'label' => __('Footer Widget Heading','vw-travel'),
        'section' => 'vw_travel_footer',
        'choices' => array(
        	'Left' => __('Left','vw-travel'),
            'Center' => __('Center','vw-travel'),
            'Right' => __('Right','vw-travel')
        ),
	) );

	$wp_customize->add_setting('vw_travel_footer_widgets_content',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_footer_widgets_content',array(
        'type' => 'select',
        'label' => __('Footer Widget Content','vw-travel'),
        'section' => 'vw_travel_footer',
        'choices' => array(
        	'Left' => __('Left','vw-travel'),
            'Center' => __('Center','vw-travel'),
            'Right' => __('Right','vw-travel')
        ),
	) );

    // footer social icon
  	$wp_customize->add_setting( 'vw_travel_footer_icon',array(
		'default' => false,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_travel_switch_sanitization'
    ) );
  	$wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_footer_icon',array(
		'label' => esc_html__( 'Show / Hide Footer Social Icon','vw-travel' ),
		'section' => 'vw_travel_footer'
    )));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_travel_footer_text', array( 
		'selector' => '#footer-2 .copyright p', 
		'render_callback' => 'vw_travel_customize_partial_vw_travel_footer_text', 
	));

	$wp_customize->add_setting( 'vw_travel_copyright_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_travel_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_copyright_hide_show',array(
      'label' => esc_html__( 'Show / Hide Copyright','vw-travel' ),
      'section' => 'vw_travel_footer'
    )));

	$wp_customize->add_setting('vw_travel_copyright_background_color', array(
		'default'           => '#0ca6ee',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_travel_copyright_background_color', array(
		'label'    => __('Copyright Background Color', 'vw-travel'),
		'section'  => 'vw_travel_footer',
	)));
	
	$wp_customize->add_setting('vw_travel_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_travel_footer_text',array(
		'label'	=> __('Copyright Text','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( 'Copyright 2019, .....', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_footer',
		'type'=> 'text'
	));	

	$wp_customize->add_setting('vw_travel_copyright_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_copyright_font_size',array(
		'label'	=> __('Copyright Font Size','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_copyright_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_copyright_padding_top_bottom',array(
		'label'	=> __('Copyright Padding Top Bottom','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_copyright_alingment',array(
        'default' => 'center',
        'sanitize_callback' => 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Travel_Image_Radio_Control($wp_customize, 'vw_travel_copyright_alingment', array(
        'type' => 'select',
        'label' => __('Copyright Alignment','vw-travel'),
        'section' => 'vw_travel_footer',
        'settings' => 'vw_travel_copyright_alingment',
        'choices' => array(
            'left' => esc_url(get_template_directory_uri()).'/assets/images/copyright1.png',
            'center' => esc_url(get_template_directory_uri()).'/assets/images/copyright2.png',
            'right' => esc_url(get_template_directory_uri()).'/assets/images/copyright3.png'
    ))));

	$wp_customize->add_setting( 'vw_travel_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_travel_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-travel' ),
      	'section' => 'vw_travel_footer'
    )));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_travel_scroll_to_top_icon', array( 
		'selector' => '.scrollup i', 
		'render_callback' => 'vw_travel_customize_partial_vw_travel_scroll_to_top_icon', 
	));

    $wp_customize->add_setting('vw_travel_scroll_to_top_icon',array(
		'default'	=> 'fas fa-angle-up',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_scroll_to_top_icon',array(
		'label'	=> __('Add Scroll to Top Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_footer',
		'setting'	=> 'vw_travel_scroll_to_top_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_travel_scroll_to_top_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_scroll_to_top_font_size',array(
		'label'	=> __('Icon Font Size','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_scroll_to_top_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_scroll_to_top_padding',array(
		'label'	=> __('Icon Top Bottom Padding','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_scroll_to_top_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_scroll_to_top_width',array(
		'label'	=> __('Icon Width','vw-travel'),
		'description'	=> __('Enter a value in pixels Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_scroll_to_top_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_scroll_to_top_height',array(
		'label'	=> __('Icon Height','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_travel_scroll_to_top_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_travel_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_travel_scroll_to_top_border_radius', array(
		'label'       => esc_html__( 'Icon Border Radius','vw-travel' ),
		'section'     => 'vw_travel_footer',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('vw_travel_scroll_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Travel_Image_Radio_Control($wp_customize, 'vw_travel_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','vw-travel'),
        'section' => 'vw_travel_footer',
        'settings' => 'vw_travel_scroll_top_alignment',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/layout2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/layout3.png'
    ))));

    //Blog Post
	
	$BlogPostParentPanel = new VW_Travel_WP_Customize_Panel( $wp_customize, 'blog_post_parent_panel', array(
		'title' => __( 'Blog Post Settings', 'vw-travel' ),
		'panel' => 'vw_travel_panel_id',
	));

	$wp_customize->add_panel( $BlogPostParentPanel );

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'vw_travel_post_settings', array(
		'title' => __( 'Post Settings', 'vw-travel' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Blog layout
    $wp_customize->add_setting('vw_travel_blog_layout_option',array(
        'default' => 'Default',
        'sanitize_callback' => 'vw_travel_sanitize_choices'
    ));
    $wp_customize->add_control(new VW_Travel_Image_Radio_Control($wp_customize, 'vw_travel_blog_layout_option', array(
        'type' => 'select',
        'label' => __('Blog Layouts','vw-travel'),
        'section' => 'vw_travel_post_settings',
        'choices' => array(
            'Default' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout2.png',
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout3.png',
    ))));

   	$wp_customize->add_setting('vw_travel_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_theme_options',array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','vw-travel'),
        'description' => __('Here you can change the sidebar layout for posts. ','vw-travel'),
        'section' => 'vw_travel_post_settings',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-travel'),
            'Right Sidebar' => __('Right Sidebar','vw-travel'),
            'One Column' => __('One Column','vw-travel'),
            'Three Columns' => __('Three Columns','vw-travel'),
            'Four Columns' => __('Four Columns','vw-travel'),
            'Grid Layout' => __('Grid Layout','vw-travel')
        ),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_travel_toggle_postdate', array( 
		'selector' => '.post-main-box h2 a', 
		'render_callback' => 'vw_travel_customize_partial_vw_travel_toggle_postdate', 
	));

  	$wp_customize->add_setting('vw_travel_toggle_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_toggle_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_post_settings',
		'setting'	=> 'vw_travel_toggle_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'vw_travel_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_travel_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_toggle_postdate',array(
        'label' => esc_html__( 'Show / Hide Post Date','vw-travel' ),
        'section' => 'vw_travel_post_settings'
    )));

    $wp_customize->add_setting('vw_travel_toggle_author_icon',array(
		'default'	=> 'far fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_toggle_author_icon',array(
		'label'	=> __('Add Author Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_post_settings',
		'setting'	=> 'vw_travel_toggle_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'vw_travel_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_travel_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_toggle_author',array(
		'label' => esc_html__( 'Show / Hide Author','vw-travel' ),
		'section' => 'vw_travel_post_settings'
    )));

    $wp_customize->add_setting('vw_travel_toggle_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_toggle_comments_icon',array(
		'label'	=> __('Add Comments Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_post_settings',
		'setting'	=> 'vw_travel_toggle_comments_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'vw_travel_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_travel_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_toggle_comments',array(
		'label' => esc_html__( 'Show / Hide Comments','vw-travel' ),
		'section' => 'vw_travel_post_settings'
    )));

    $wp_customize->add_setting('vw_travel_toggle_time_icon',array(
		'default'	=> 'fas fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_toggle_time_icon',array(
		'label'	=> __('Add Time Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_post_settings',
		'setting'	=> 'vw_travel_toggle_time_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'vw_travel_toggle_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_travel_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_toggle_time',array(
		'label' => esc_html__( 'Show / Hide Time','vw-travel' ),
		'section' => 'vw_travel_post_settings'
    )));

    $wp_customize->add_setting( 'vw_travel_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_travel_switch_sanitization'
	));
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_featured_image_hide_show', array(
		'label' => esc_html__( 'Show / Hide Featured Image','vw-travel' ),
		'section' => 'vw_travel_post_settings'
    )));

    $wp_customize->add_setting( 'vw_travel_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_travel_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_travel_featured_image_border_radius', array(
		'label'       => esc_html__( 'Featured Image Border Radius','vw-travel' ),
		'section'     => 'vw_travel_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'vw_travel_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_travel_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_travel_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Featured Image Box Shadow','vw-travel' ),
		'section'     => 'vw_travel_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Featured Image
	$wp_customize->add_setting('vw_travel_blog_post_featured_image_dimension',array(
	       'default' => 'default',
	       'sanitize_callback'	=> 'vw_travel_sanitize_choices'
	));
  	$wp_customize->add_control('vw_travel_blog_post_featured_image_dimension',array(
     'type' => 'select',
     'label'	=> __('Blog Post Featured Image Dimension','vw-travel'),
     'section'	=> 'vw_travel_post_settings',
     'choices' => array(
          'default' => __('Default','vw-travel'),
          'custom' => __('Custom Image Size','vw-travel'),
      ),
  	));

	$wp_customize->add_setting('vw_travel_blog_post_featured_image_custom_width',array(
			'default'=> '',
			'sanitize_callback'	=> 'sanitize_text_field'
		));
	$wp_customize->add_control('vw_travel_blog_post_featured_image_custom_width',array(
			'label'	=> __('Featured Image Custom Width','vw-travel'),
			'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
			'input_attrs' => array(
	    'placeholder' => __( '10px', 'vw-travel' ),),
			'section'=> 'vw_travel_post_settings',
			'type'=> 'text',
			'active_callback' => 'vw_travel_blog_post_featured_image_dimension'
		));

	$wp_customize->add_setting('vw_travel_blog_post_featured_image_custom_height',array(
			'default'=> '',
			'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_blog_post_featured_image_custom_height',array(
			'label'	=> __('Featured Image Custom Height','vw-travel'),
			'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
			'input_attrs' => array(
	    'placeholder' => __( '10px', 'vw-travel' ),),
			'section'=> 'vw_travel_post_settings',
			'type'=> 'text',
			'active_callback' => 'vw_travel_blog_post_featured_image_dimension'
	));

    $wp_customize->add_setting( 'vw_travel_excerpt_number', array(
		'default'              => 30,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_travel_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_travel_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-travel' ),
		'section'     => 'vw_travel_post_settings',
		'type'        => 'range',
		'settings'    => 'vw_travel_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('vw_travel_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','vw-travel'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','vw-travel'),
		'section'=> 'vw_travel_post_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('vw_travel_blog_page_posts_settings',array(
        'default' => 'Into Blocks',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_blog_page_posts_settings',array(
        'type' => 'select',
        'label' => __('Display Blog Posts','vw-travel'),
        'section' => 'vw_travel_post_settings',
        'choices' => array(
        	'Into Blocks' => __('Into Blocks','vw-travel'),
            'Without Blocks' => __('Without Blocks','vw-travel')
        ),
	) );

    $wp_customize->add_setting('vw_travel_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_excerpt_settings',array(
        'type' => 'select',
        'label' => __('Post Content','vw-travel'),
        'section' => 'vw_travel_post_settings',
        'choices' => array(
        	'Content' => __('Content','vw-travel'),
            'Excerpt' => __('Excerpt','vw-travel'),
            'No Content' => __('No Content','vw-travel')
        ),
	) );

	$wp_customize->add_setting('vw_travel_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_post_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_travel_blog_pagination_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_travel_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_blog_pagination_hide_show',array(
      'label' => esc_html__( 'Show / Hide Blog Pagination','vw-travel' ),
      'section' => 'vw_travel_post_settings'
    )));

	$wp_customize->add_setting( 'vw_travel_blog_pagination_type', array(
        'default'			=> 'blog-page-numbers',
        'sanitize_callback'	=> 'vw_travel_sanitize_choices'
    ));
    $wp_customize->add_control( 'vw_travel_blog_pagination_type', array(
        'section' => 'vw_travel_post_settings',
        'type' => 'select',
        'label' => __( 'Blog Pagination', 'vw-travel' ),
        'choices'		=> array(
            'blog-page-numbers'  => __( 'Numeric', 'vw-travel' ),
            'next-prev' => __( 'Older Posts/Newer Posts', 'vw-travel' ),
    )));

    // Button Settings
	$wp_customize->add_section( 'vw_travel_button_settings', array(
		'title' => __( 'Button Settings', 'vw-travel' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_travel_button_text', array( 
		'selector' => '.post-main-box .more-btn a', 
		'render_callback' => 'vw_travel_customize_partial_vw_travel_button_text', 
	));

	$wp_customize->add_setting('vw_travel_button_text',array(
		'default'=> esc_html__( 'Read More', 'vw-travel' ),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_button_text',array(
		'label'	=> __('Add Button Text','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( 'Read More', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_blog_button_icon',array(
		'default'	=> 'fas fa-long-arrow-alt-right',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_blog_button_icon',array(
		'label'	=> __('Add Button Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_button_settings',
		'setting'	=> 'vw_travel_blog_button_icon',
		'type'		=> 'icon'
	)));

	// font size button
	$wp_customize->add_setting('vw_travel_button_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_button_font_size',array(
		'label'	=> __('Button Font Size','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
      	'placeholder' => __( '10px', 'vw-travel' ),
    ),
    	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'vw_travel_button_settings',
	));

	$wp_customize->add_setting( 'vw_travel_button_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_travel_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_travel_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','vw-travel' ),
		'section'     => 'vw_travel_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('vw_travel_button_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_button_padding_top_bottom',array(
		'label'	=> __('Padding Top Bottom','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_button_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_button_padding_left_right',array(
		'label'	=> __('Padding Left Right','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_button_settings',
		'type'=> 'text'
	));

	// text trasform
	$wp_customize->add_setting('vw_travel_button_text_transform',array(
		'default'=> 'Uppercase',
		'sanitize_callback'	=> 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_button_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Button Text Transform','vw-travel'),
		'choices' => array(
            'Uppercase' => __('Uppercase','vw-travel'),
            'Capitalize' => __('Capitalize','vw-travel'),
            'Lowercase' => __('Lowercase','vw-travel'),
        ),
		'section'=> 'vw_travel_button_settings',
	));

	$wp_customize->add_setting('vw_travel_button_letter_spacing',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_button_letter_spacing',array(
		'label'	=> __('Button Letter Spacing','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
      	'placeholder' => __( '10px', 'vw-travel' ),
    ),
    	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'vw_travel_button_settings',
	));

	// Related Post Settings
	$wp_customize->add_section( 'vw_travel_related_posts_settings', array(
		'title' => __( 'Related Posts Settings', 'vw-travel' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_travel_related_post_title', array( 
		'selector' => '.related-post h3', 
		'render_callback' => 'vw_travel_customize_partial_vw_travel_related_post_title', 
	));

    $wp_customize->add_setting( 'vw_travel_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_travel_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_related_post',array(
		'label' => esc_html__( 'Show / Hide Related Post','vw-travel' ),
		'section' => 'vw_travel_related_posts_settings'
    )));

    $wp_customize->add_setting('vw_travel_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_related_post_title',array(
		'label'	=> __('Add Related Post Title','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( 'Related Post', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('vw_travel_related_posts_count',array(
		'default'=> '3',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_related_posts_count',array(
		'label'	=> __('Add Related Post Count','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '3', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_related_posts_settings',
		'type'=> 'number'
	));

	$wp_customize->add_setting( 'vw_travel_related_posts_excerpt_number', array(
		'default'              => 20,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_travel_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_travel_related_posts_excerpt_number', array(
		'label'       => esc_html__( 'Related Posts Excerpt length','vw-travel' ),
		'section'     => 'vw_travel_related_posts_settings',
		'type'        => 'range',
		'settings'    => 'vw_travel_related_posts_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	// Single Posts Settings
	$wp_customize->add_section( 'vw_travel_single_blog_settings', array(
		'title' => __( 'Single Post Settings', 'vw-travel' ),
		'panel' => 'blog_post_parent_panel',
	));

  	$wp_customize->add_setting('vw_travel_single_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_single_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_single_blog_settings',
		'setting'	=> 'vw_travel_single_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'vw_travel_single_postdate',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'vw_travel_switch_sanitization'
	) );
	$wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_single_postdate',array(
	    'label' => esc_html__( 'Show / Hide Date','vw-travel' ),
	   'section' => 'vw_travel_single_blog_settings'
	)));

	$wp_customize->add_setting('vw_travel_single_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_single_author_icon',array(
		'label'	=> __('Add Author Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_single_blog_settings',
		'setting'	=> 'vw_travel_single_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'vw_travel_single_author',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'vw_travel_switch_sanitization'
	) );
	$wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_single_author',array(
	    'label' => esc_html__( 'Show / Hide Author','vw-travel' ),
	    'section' => 'vw_travel_single_blog_settings'
	)));

   	$wp_customize->add_setting('vw_travel_single_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_single_comments_icon',array(
		'label'	=> __('Add Comments Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_single_blog_settings',
		'setting'	=> 'vw_travel_single_comments_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'vw_travel_single_comments',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'vw_travel_switch_sanitization'
	) );
	$wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_single_comments',array(
	    'label' => esc_html__( 'Show / Hide Comments','vw-travel' ),
	    'section' => 'vw_travel_single_blog_settings'
	)));

  	$wp_customize->add_setting('vw_travel_single_time_icon',array(
		'default'	=> 'fas fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_single_time_icon',array(
		'label'	=> __('Add Time Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_single_blog_settings',
		'setting'	=> 'vw_travel_single_time_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'vw_travel_single_time',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'vw_travel_switch_sanitization'
	) );
	$wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_single_time',array(
	    'label' => esc_html__( 'Show / Hide Time','vw-travel' ),
	    'section' => 'vw_travel_single_blog_settings'
	)));

	$wp_customize->add_setting( 'vw_travel_single_post_breadcrumb',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_travel_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_single_post_breadcrumb',array(
		'label' => esc_html__( 'Show / Hide Breadcrumb','vw-travel' ),
		'section' => 'vw_travel_single_blog_settings'
    )));

    // Single Posts Category
  	$wp_customize->add_setting( 'vw_travel_single_post_category',array(
		'default' => true,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_travel_switch_sanitization'
    ) );
  	$wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_single_post_category',array(
		'label' => esc_html__( 'Show / Hide Category','vw-travel' ),
		'section' => 'vw_travel_single_blog_settings'
    )));

	$wp_customize->add_setting( 'vw_travel_toggle_tags',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_travel_switch_sanitization'
	));
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_toggle_tags', array(
		'label' => esc_html__( 'Show / Hide Tags','vw-travel' ),
		'section' => 'vw_travel_single_blog_settings'
    )));

    $wp_customize->add_setting('vw_travel_single_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_single_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','vw-travel'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','vw-travel'),
		'section'=> 'vw_travel_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_travel_single_blog_post_navigation_show_hide',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_travel_switch_sanitization'
	));
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_single_blog_post_navigation_show_hide', array(
		'label' => esc_html__( 'Show / Hide Post Navigation','vw-travel' ),
		'section' => 'vw_travel_single_blog_settings'
    )));

	//navigation text
	$wp_customize->add_setting('vw_travel_single_blog_prev_navigation_text',array(
		'default'=> 'PREVIOUS',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_single_blog_prev_navigation_text',array(
		'label'	=> __('Post Navigation Text','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( 'PREVIOUS', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_single_blog_next_navigation_text',array(
		'default'=> 'NEXT',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_single_blog_next_navigation_text',array(
		'label'	=> __('Post Navigation Text','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( 'NEXT', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_single_blog_comment_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_travel_single_blog_comment_title',array(
		'label'	=> __('Add Comment Title','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( 'Leave a Reply', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_single_blog_comment_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_travel_single_blog_comment_button_text',array(
		'label'	=> __('Add Comment Button Text','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( 'Post Comment', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_single_blog_comment_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_single_blog_comment_width',array(
		'label'	=> __('Comment Form Width','vw-travel'),
		'description'	=> __('Enter a value in %. Example:50%','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '100%', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_single_blog_settings',
		'type'=> 'text'
	));

	// Grid layout setting
	$wp_customize->add_section( 'vw_travel_grid_layout_settings', array(
		'title' => __( 'Grid Layout Settings', 'vw-travel' ),
		'panel' => 'blog_post_parent_panel',
	));

  	$wp_customize->add_setting('vw_travel_grid_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_grid_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_grid_layout_settings',
		'setting'	=> 'vw_travel_grid_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'vw_travel_grid_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_travel_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_grid_postdate',array(
        'label' => esc_html__( 'Show / Hide Post Date','vw-travel' ),
        'section' => 'vw_travel_grid_layout_settings'
    )));

	$wp_customize->add_setting('vw_travel_grid_author_icon',array(
		'default'	=> 'far fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_grid_author_icon',array(
		'label'	=> __('Add Author Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_grid_layout_settings',
		'setting'	=> 'vw_travel_grid_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'vw_travel_grid_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_travel_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_grid_author',array(
		'label' => esc_html__( 'Show / Hide Author','vw-travel' ),
		'section' => 'vw_travel_grid_layout_settings'
    )));

   	$wp_customize->add_setting('vw_travel_grid_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_grid_comments_icon',array(
		'label'	=> __('Add Comments Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_grid_layout_settings',
		'setting'	=> 'vw_travel_grid_comments_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'vw_travel_grid_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_travel_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_grid_comments',array(
		'label' => esc_html__( 'Show / Hide Comments','vw-travel' ),
		'section' => 'vw_travel_grid_layout_settings'
    )));

 	$wp_customize->add_setting('vw_travel_grid_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_grid_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','vw-travel'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','vw-travel'),
		'section'=> 'vw_travel_grid_layout_settings',
		'type'=> 'text'
	));  

  	$wp_customize->add_setting('vw_travel_display_grid_posts_settings',array(
	    'default' => 'Into Blocks',
	    'transport' => 'refresh',
	    'sanitize_callback' => 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_display_grid_posts_settings',array(
	    'type' => 'select',
	    'label' => __('Display Grid Posts','vw-travel'),
	    'section' => 'vw_travel_grid_layout_settings',
	    'choices' => array(
	    	'Into Blocks' => __('Into Blocks','vw-travel'),
	      'Without Blocks' => __('Without Blocks','vw-travel')
	      ),
	) );

	$wp_customize->add_setting('vw_travel_grid_button_text',array(
		'default'=> esc_html__('Read More','vw-travel'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_grid_button_text',array(
		'label'	=> esc_html__('Add Button Text','vw-travel'),
		'input_attrs' => array(
        'placeholder' => esc_html__( 'Read More', 'vw-travel' ),
      ),
		'section'=> 'vw_travel_grid_layout_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('vw_travel_grid_button_icon',array(
		'default'	=> 'fas fa-long-arrow-alt-right',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_grid_button_icon',array(
		'label'	=> __('Add Button Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_grid_layout_settings',
		'setting'	=> 'vw_travel_grid_button_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_travel_grid_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_grid_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_grid_layout_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_grid_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_grid_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Grid Post Content','vw-travel'),
        'section' => 'vw_travel_grid_layout_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','vw-travel'),
            'Excerpt' => esc_html__('Excerpt','vw-travel'),
            'No Content' => esc_html__('No Content','vw-travel')
        ),
	) );

   // other settings
	$OtherParentPanel = new VW_Travel_WP_Customize_Panel( $wp_customize, 'vw_travel_other_panel_id', array(
		'title' => __( 'Others Settings', 'vw-travel' ),
		'panel' => 'vw_travel_panel_id',
	));

	$wp_customize->add_panel( $OtherParentPanel );

	// Layout
	$wp_customize->add_section( 'vw_travel_left_right', array(
    	'title'      => esc_html__( 'General Settings', 'vw-travel' ),
		'panel' => 'vw_travel_other_panel_id'
	) );

	$wp_customize->add_setting('vw_travel_width_option',array(
        'default' => 'Full Width',
        'sanitize_callback' => 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Travel_Image_Radio_Control($wp_customize, 'vw_travel_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','vw-travel'),
        'description' => __('Here you can change the width layout of Website.','vw-travel'),
        'section' => 'vw_travel_left_right',
        'choices' => array(
            'Full Width' => esc_url(get_template_directory_uri()).'/assets/images/full-width.png',
            'Wide Width' => esc_url(get_template_directory_uri()).'/assets/images/wide-width.png',
            'Boxed' => esc_url(get_template_directory_uri()).'/assets/images/boxed-width.png',
        ))));

	$wp_customize->add_setting('vw_travel_page_layout',array(
        'default' => 'One Column',
        'sanitize_callback' => 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','vw-travel'),
        'description' => __('Here you can change the sidebar layout for pages. ','vw-travel'),
        'section' => 'vw_travel_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-travel'),
            'Right Sidebar' => __('Right Sidebar','vw-travel'),
            'One Column' => __('One Column','vw-travel')
        ),
	) );

	$wp_customize->add_setting( 'vw_travel_single_page_breadcrumb',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_travel_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_single_page_breadcrumb',array(
		'label' => esc_html__( 'Show / Hide Page Breadcrumb','vw-travel' ),
		'section' => 'vw_travel_left_right'
    )));

	//Wow Animation
	$wp_customize->add_setting( 'vw_travel_animation',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_travel_switch_sanitization'
    ));
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_animation',array(
        'label' => esc_html__( 'Show / Hide Animation ','vw-travel' ),
        'description' => __('Here you can disable overall site animation effect','vw-travel'),
        'section' => 'vw_travel_left_right'
    )));

    $wp_customize->add_setting('vw_travel_reset_all_settings',array(
      'sanitize_callback'	=> 'sanitize_text_field',
   	));
   	$wp_customize->add_control(new VW_Travel_Reset_Custom_Control($wp_customize, 'vw_travel_reset_all_settings',array(
      'type' => 'reset_control',
      'label' => __('Reset All Settings', 'vw-travel'),
      'description' => 'vw_travel_reset_all_settings',
      'section' => 'vw_travel_left_right'
   	)));

	//Pre-Loader
	$wp_customize->add_setting( 'vw_travel_loader_enable',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_travel_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_loader_enable',array(
        'label' => esc_html__( 'Show / Hide Pre-Loader','vw-travel' ),
        'section' => 'vw_travel_left_right'
    )));

	$wp_customize->add_setting('vw_travel_preloader_bg_color', array(
		'default'           => '#0ca6ee',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_travel_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'vw-travel'),
		'section'  => 'vw_travel_left_right',
	)));

	$wp_customize->add_setting('vw_travel_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_travel_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'vw-travel'),
		'section'  => 'vw_travel_left_right',
	)));

	$wp_customize->add_setting('vw_travel_preloader_bg_img',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'vw_travel_preloader_bg_img',array(
        'label' => __('Preloader Background Image','vw-travel'),
        'section' => 'vw_travel_left_right'
	)));

    //404 Page Setting
	$wp_customize->add_section('vw_travel_404_page',array(
		'title'	=> __('404 Page Settings','vw-travel'),
		'panel' => 'vw_travel_other_panel_id',
	));	

	$wp_customize->add_setting('vw_travel_404_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_travel_404_page_title',array(
		'label'	=> __('Add Title','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '404 Not Found', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_404_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_travel_404_page_content',array(
		'label'	=> __('Add Text','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( 'Looks like you have taken a wrong turn, Dont worry, it happens to the best of us.', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_404_page_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_404_page_button_text',array(
		'label'	=> __('Add Button Text','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( 'Go Back', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_404_page_button_icon',array(
		'default'	=> 'fas fa-long-arrow-alt-right',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_404_page_button_icon',array(
		'label'	=> __('Add Button Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_404_page',
		'setting'	=> 'vw_travel_404_page_button_icon',
		'type'		=> 'icon'
	)));

	//No Result Page Setting
	$wp_customize->add_section('vw_travel_no_results_page',array(
		'title'	=> __('No Results Page Settings','vw-travel'),
		'panel' => 'vw_travel_other_panel_id',
	));	

	$wp_customize->add_setting('vw_travel_no_results_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_travel_no_results_page_title',array(
		'label'	=> __('Add Title','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( 'Nothing Found', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_no_results_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_no_results_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_travel_no_results_page_content',array(
		'label'	=> __('Add Text','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_no_results_page',
		'type'=> 'text'
	));

	//Social Icon Setting
	$wp_customize->add_section('vw_travel_social_icon_settings',array(
		'title'	=> __('Social Icons Settings','vw-travel'),
		'panel' => 'vw_travel_other_panel_id',
	));	

	$wp_customize->add_setting('vw_travel_social_icon_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_social_icon_font_size',array(
		'label'	=> __('Icon Font Size','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_social_icon_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_social_icon_padding',array(
		'label'	=> __('Icon Padding','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_social_icon_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_social_icon_width',array(
		'label'	=> __('Icon Width','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_social_icon_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_social_icon_height',array(
		'label'	=> __('Icon Height','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_travel_social_icon_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_travel_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_travel_social_icon_border_radius', array(
		'label'       => esc_html__( 'Icon Border Radius','vw-travel' ),
		'section'     => 'vw_travel_social_icon_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Responsive Media Settings
	$wp_customize->add_section('vw_travel_responsive_media',array(
		'title'	=> __('Responsive Media','vw-travel'),
		'panel' => 'vw_travel_other_panel_id',
	));

	$wp_customize->add_setting( 'vw_travel_resp_topbar_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_travel_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_resp_topbar_hide_show',array(
      'label' => esc_html__( 'Show / Hide Topbar','vw-travel' ),
      'section' => 'vw_travel_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_travel_stickyheader_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_travel_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_stickyheader_hide_show',array(
      'label' => esc_html__( 'Show / Hide Sticky Header','vw-travel' ),
      'section' => 'vw_travel_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_travel_resp_slider_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_travel_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_resp_slider_hide_show',array(
      'label' => esc_html__( 'Show / Hide Slider','vw-travel' ),
      'section' => 'vw_travel_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_travel_sidebar_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_travel_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_sidebar_hide_show',array(
      'label' => esc_html__( 'Show / Hide Sidebar','vw-travel' ),
      'section' => 'vw_travel_responsive_media'
    )));

     $wp_customize->add_setting( 'vw_travel_resp_scroll_top_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_travel_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_resp_scroll_top_hide_show',array(
      'label' => esc_html__( 'Show / Hide Scroll To Top','vw-travel' ),
      'section' => 'vw_travel_responsive_media'
    )));

    $wp_customize->add_setting('vw_travel_resp_menu_toggle_btn_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_travel_resp_menu_toggle_btn_bg_color', array(
		'label'    => __('Toggle Button Bg Color', 'vw-travel'),
		'section'  => 'vw_travel_responsive_media',
	)));

    $wp_customize->add_setting('vw_travel_res_open_menu_icon',array(
		'default'	=> 'fas fa-bars',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_res_open_menu_icon',array(
		'label'	=> __('Add Open Menu Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_responsive_media',
		'setting'	=> 'vw_travel_res_open_menu_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_travel_res_close_menus_icon',array(
		'default'	=> 'fas fa-times',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Travel_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_travel_res_close_menus_icon',array(
		'label'	=> __('Add Close Menu Icon','vw-travel'),
		'transport' => 'refresh',
		'section'	=> 'vw_travel_responsive_media',
		'setting'	=> 'vw_travel_res_close_menus_icon',
		'type'		=> 'icon'
	)));

	
    //Woocommerce settings
	$wp_customize->add_section('vw_travel_woocommerce_section', array(
		'title'    => __('WooCommerce Layout', 'vw-travel'),
		'priority' => null,
		'panel'    => 'woocommerce',
	));

    //Shop Page Featured Image
	$wp_customize->add_setting( 'vw_travel_shop_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_travel_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_travel_shop_featured_image_border_radius', array(
		'label'       => esc_html__( 'Shop Page Featured Image Border Radius','vw-travel' ),
		'section'     => 'vw_travel_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'vw_travel_shop_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_travel_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_travel_shop_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Shop Page Featured Image Box Shadow','vw-travel' ),
		'section'     => 'vw_travel_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_travel_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product #sidebar', 
		'render_callback' => 'vw_travel_customize_partial_vw_travel_woocommerce_shop_page_sidebar', ) );

    //Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'vw_travel_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_travel_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Show / Hide Shop Page Sidebar','vw-travel' ),
		'section' => 'vw_travel_woocommerce_section'
    )));

    $wp_customize->add_setting('vw_travel_shop_page_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_shop_page_layout',array(
        'type' => 'select',
        'label' => __('Shop Page Sidebar Layout','vw-travel'),
        'section' => 'vw_travel_woocommerce_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-travel'),
            'Right Sidebar' => __('Right Sidebar','vw-travel'),
        ),
	) );

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_travel_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product #sidebar', 
		'render_callback' => 'vw_travel_customize_partial_vw_travel_woocommerce_single_product_page_sidebar', ) );

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'vw_travel_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_travel_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Show / Hide Single Product Sidebar','vw-travel' ),
		'section' => 'vw_travel_woocommerce_section'
    )));

    $wp_customize->add_setting('vw_travel_single_product_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_single_product_layout',array(
        'type' => 'select',
        'label' => __('Single Product Sidebar Layout','vw-travel'),
        'section' => 'vw_travel_woocommerce_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-travel'),
            'Right Sidebar' => __('Right Sidebar','vw-travel'),
        ),
	) );

    //Products per page
    $wp_customize->add_setting('vw_travel_products_per_page',array(
		'default'=> '9',
		'sanitize_callback'	=> 'vw_travel_sanitize_float'
	));
	$wp_customize->add_control('vw_travel_products_per_page',array(
		'label'	=> __('Products Per Page','vw-travel'),
		'description' => __('Display on shop page','vw-travel'),
		'input_attrs' => array(
            'step'             => 1,
			'min'              => 0,
			'max'              => 50,
        ),
		'section'=> 'vw_travel_woocommerce_section',
		'type'=> 'number',
	));

    //Products per row
    $wp_customize->add_setting('vw_travel_products_per_row',array(
		'default'=> '3',
		'sanitize_callback'	=> 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_products_per_row',array(
		'label'	=> __('Products Per Row','vw-travel'),
		'description' => __('Display on shop page','vw-travel'),
		'choices' => array(
            '2' => '2',
			'3' => '3',
			'4' => '4',
        ),
		'section'=> 'vw_travel_woocommerce_section',
		'type'=> 'select',
	));

	//Products padding
	$wp_customize->add_setting('vw_travel_products_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_products_padding_top_bottom',array(
		'label'	=> __('Products Padding Top Bottom','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_products_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_products_padding_left_right',array(
		'label'	=> __('Products Padding Left Right','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_woocommerce_section',
		'type'=> 'text'
	));

	//Products box shadow
	$wp_customize->add_setting( 'vw_travel_products_box_shadow', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_travel_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_travel_products_box_shadow', array(
		'label'       => esc_html__( 'Products Box Shadow','vw-travel' ),
		'section'     => 'vw_travel_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Products border radius
    $wp_customize->add_setting( 'vw_travel_products_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_travel_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_travel_products_border_radius', array(
		'label'       => esc_html__( 'Products Border Radius','vw-travel' ),
		'section'     => 'vw_travel_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'vw_travel_products_button_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_travel_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_travel_products_button_border_radius', array(
		'label'       => esc_html__( 'Products Button Border Radius','vw-travel' ),
		'section'     => 'vw_travel_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Products Sale Badge
	$wp_customize->add_setting('vw_travel_woocommerce_sale_position',array(
        'default' => 'right',
        'sanitize_callback' => 'vw_travel_sanitize_choices'
	));
	$wp_customize->add_control('vw_travel_woocommerce_sale_position',array(
        'type' => 'select',
        'label' => __('Sale Badge Position','vw-travel'),
        'section' => 'vw_travel_woocommerce_section',
        'choices' => array(
            'left' => __('Left','vw-travel'),
            'right' => __('Right','vw-travel'),
        ),
	) );

	$wp_customize->add_setting('vw_travel_woocommerce_sale_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_woocommerce_sale_font_size',array(
		'label'	=> __('Sale Font Size','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_woocommerce_sale_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_woocommerce_sale_padding_top_bottom',array(
		'label'	=> __('Sale Padding Top Bottom','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_travel_woocommerce_sale_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_travel_woocommerce_sale_padding_left_right',array(
		'label'	=> __('Sale Padding Left Right','vw-travel'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-travel'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-travel' ),
        ),
		'section'=> 'vw_travel_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_travel_woocommerce_sale_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_travel_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_travel_woocommerce_sale_border_radius', array(
		'label'       => esc_html__( 'Sale Border Radius','vw-travel' ),
		'section'     => 'vw_travel_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );	

  	// Related Product
    $wp_customize->add_setting( 'vw_travel_related_product_show_hide',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_travel_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Travel_Toggle_Switch_Custom_Control( $wp_customize, 'vw_travel_related_product_show_hide',array(
        'label' => esc_html__( 'Show / Hide Related Product','vw-travel' ),
        'section' => 'vw_travel_woocommerce_section'
    )));

    // Has to be at the top
	$wp_customize->register_panel_type( 'VW_Travel_WP_Customize_Panel' );
	$wp_customize->register_section_type( 'VW_Travel_WP_Customize_Section' );

}

add_action( 'customize_register', 'vw_travel_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

if ( class_exists( 'WP_Customize_Panel' ) ) {
  	class VW_Travel_WP_Customize_Panel extends WP_Customize_Panel {
	    public $panel;
	    public $type = 'vw_travel_panel';
	    public function json() {

	      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'type', 'panel', ) );
	      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
	      $array['content'] = $this->get_content();
	      $array['active'] = $this->active();
	      $array['instanceNumber'] = $this->instance_number;
	      return $array;
    	}
  	}
}

if ( class_exists( 'WP_Customize_Section' ) ) {
  	class VW_Travel_WP_Customize_Section extends WP_Customize_Section {
	    public $section;
	    public $type = 'vw_travel_section';
	    public function json() {

	      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'panel', 'type', 'description_hidden', 'section', ) );
	      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
	      $array['content'] = $this->get_content();
	      $array['active'] = $this->active();
	      $array['instanceNumber'] = $this->instance_number;

	      if ( $this->panel ) {
	        $array['customizeAction'] = sprintf( 'Customizing &#9656; %s', esc_html( $this->manager->get_panel( $this->panel )->title ) );
	      } else {
	        $array['customizeAction'] = 'Customizing';
	      }
	      return $array;
    	}
  	}
}

// Enqueue our scripts and styles
function vw_travel_customize_controls_scripts() {
	wp_enqueue_script( 'customizer-controls', get_theme_file_uri( '/assets/js/customizer-controls.js' ), array(), '1.0', true );
}
add_action( 'customize_controls_enqueue_scripts', 'vw_travel_customize_controls_scripts' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Travel_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Travel_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(new VW_Travel_Customize_Section_Pro($manager,'vw_travel_upgrade_pro_link',	array(
			'priority'   => 1,
			'title'    => esc_html__( 'VW TRAVEL PRO', 'vw-travel' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'vw-travel' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/wordpress-travel-theme/'),
		)));

		// Register sections.
		$manager->add_section(new VW_Travel_Customize_Section_Pro($manager,'vw_travel_get_started_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'vw-travel' ),
			'pro_text' => esc_html__( 'DOCS', 'vw-travel' ),
			'pro_url'  => esc_url('https://preview.vwthemesdemo.com/docs/free-vw-travel/'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-travel-customize-controls', trailingslashit( esc_url(get_template_directory_uri()) ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-travel-customize-controls', trailingslashit( esc_url(get_template_directory_uri()) ) . '/assets/css/customize-controls.css' );

		wp_localize_script(
		'vw-travel-customize-controls',
		'vw_travel_customizer_params',
		array(
			'ajaxurl' =>admin_url( 'admin-ajax.php' )
		));
	}
}

// Doing this customizer thang!
VW_Travel_Customize::get_instance();